@@ -465,6 +465,7 @@ skip_impl = (
     'virNodeGetFreePages',
     'virNetworkGetDHCPLeases',
     'virDomainBlockCopy',
+    'virNodeAllocPages',
 )
 
 lxc_skip_impl = (
@@ -708,12 +709,16 @@ def print_function_wrapper(module, name, output, export, include):
         else:
             c_call = "\n    c_retval = %s(%s);\n" % (name, c_call)
         ret_convert = "    py_retval = libvirt_%sWrap((%s) c_retval);\n" % (n,c)
+        if n == "charPtr":
+            ret_convert = ret_convert + "    free(c_retval);\n"
         ret_convert = ret_convert + "    return py_retval;\n"
     elif ret[0] in py_return_types:
         (f, t, n, c) = py_return_types[ret[0]]
         c_return = "    %s c_retval;\n" % (ret[0])
         c_call = "\n    c_retval = %s(%s);\n" % (name, c_call)
         ret_convert = "    py_retval = libvirt_%sWrap((%s) c_retval);\n" % (n,c)
+        if n == "charPtr":
+            ret_convert = ret_convert + "    free(c_retval);\n"
         ret_convert = ret_convert + "    return py_retval;\n"
     else:
         if ret[0] in skipped_types:
